[![pipeline status](https://gitlab.com/crosenbrock/app-datakeeper/badges/master/pipeline.svg)](https://gitlab.com/crosenbrock/app-datakeeper/commits/master)
[![coverage report](https://gitlab.com/crosenbrock/app-datakeeper/badges/master/coverage.svg)](https://gitlab.com/crosenbrock/app-datakeeper/commits/master)

# Data Keeper Templated System

This is a python-based project that generates other repositories for generalized
data privacy and consent systems.
